==> nifi-client-dto-1.3.0-sources.jar: org/apache/nifi/web/api/dto/UserGroupDTO.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.web.api.dto;

import com.wordnik.swagger.annotations.ApiModelProperty;
import org.apache.nifi.web.api.entity.AccessPolicyEntity;
import org.apache.nifi.web.api.entity.TenantEntity;

import javax.xml.bind.annotation.XmlType;
import java.util.Set;

/**
 * A user group in this NiFi.
 */
@XmlType(name = "userGroup")
public class UserGroupDTO extends TenantDTO {

    private Set<TenantEntity> users;
    private Set<AccessPolicyEntity> accessPolicies;

    /**
     * @return users in this group
     */
    @ApiModelProperty(value = "The users that belong to the user group.")
    public Set<TenantEntity> getUsers() {
        return users;
    }

    public void setUsers(Set<TenantEntity> users) {
        this.users = users;
    }

    /**
     * @return policies this user group is part of
     */
    @ApiModelProperty(
            value = "The access policies this user group belongs to. This field was incorrectly defined as an AccessPolicyEntity. For "
                    + "compatibility reasons the field will remain of this type, however only the fields that are present in the "
                    + "AccessPolicySummaryEntity will be populated here.",
            readOnly = true
    )
    public Set<AccessPolicyEntity> getAccessPolicies() {
        return accessPolicies;
    }

    public void setAccessPolicies(Set<AccessPolicyEntity> accessPolicies) {
        this.accessPolicies = accessPolicies;
    }
}

==> nifi-client-dto-1.6.0-sources.jar: org/apache/nifi/web/api/dto/UserGroupDTO.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.web.api.dto;

import io.swagger.annotations.ApiModelProperty;
import org.apache.nifi.web.api.entity.AccessPolicyEntity;
import org.apache.nifi.web.api.entity.TenantEntity;

import javax.xml.bind.annotation.XmlType;
import java.util.Set;

/**
 * A user group in this NiFi.
 */
@XmlType(name = "userGroup")
public class UserGroupDTO extends TenantDTO {

    private Set<TenantEntity> users;
    private Set<AccessPolicyEntity> accessPolicies;

    /**
     * @return users in this group
     */
    @ApiModelProperty(value = "The users that belong to the user group.")
    public Set<TenantEntity> getUsers() {
        return users;
    }

    public void setUsers(Set<TenantEntity> users) {
        this.users = users;
    }

    /**
     * @return policies this user group is part of
     */
    @ApiModelProperty(
            value = "The access policies this user group belongs to. This field was incorrectly defined as an AccessPolicyEntity. For "
                    + "compatibility reasons the field will remain of this type, however only the fields that are present in the "
                    + "AccessPolicySummaryEntity will be populated here.",
            readOnly = true
    )
    public Set<AccessPolicyEntity> getAccessPolicies() {
        return accessPolicies;
    }

    public void setAccessPolicies(Set<AccessPolicyEntity> accessPolicies) {
        this.accessPolicies = accessPolicies;
    }
}
